#
# spec file for package libad9361-iio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define libname libad9361
Name:           libad9361-iio
Version:        0.3
Release:        2.4
Summary:        Library for AD9361
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/analogdevicesinc/libad9361
#Git-Clone:     https://github.com/analogdevicesinc/libad9361-iio.git
Source:         https://github.com/analogdevicesinc/libad9361-iio/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         %{name}-lib-dir.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  texlive-dot2texi
BuildRequires:  pkgconfig(libiio)

%description
This is a simple library used for userspace, which manages multi-chip sync, on
platforms (FMCOMMS5) where multiple AD9361 devices are used.

%package -n %{libname}-%{sover}
Summary:        Library for AD9361
Group:          Hardware/Other

%description -n %{libname}-%{sover}
This is a simple library used for userspace, which manages multi-chip sync, on
platforms (FMCOMMS5) where multiple AD9361 devices are used.

%package devel
Summary:        Development files for libad9361
Group:          Development/Libraries/Other
Requires:       %{libname}-%{sover} = %{version}

%description devel
This is a simple library used for userspace, which manages multi-chip sync, on
platforms (FMCOMMS5) where multiple AD9361 devices are used.

%package devel-doc
Summary:        Documentation for libad9361-iio
Group:          Documentation/Other
BuildArch:      noarch

%description devel-doc
Documentation for libad9361-iio library.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_SHARED_LINKER_FLAGS=""
%make_build

%install
%cmake_install
%fdupes %{buildroot}

#move docs
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/ad93610-doc/html %{buildroot}%{_docdir}/%{name}

%post -n %{libname}-%{sover} -p /sbin/ldconfig
%postun -n %{libname}-%{sover} -p /sbin/ldconfig

%files -n %{libname}-%{sover}
%license LICENSE
%doc README.md
%{_libdir}/libad9361.so.%{sover}*
%dir %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/html

%files devel
%{_includedir}/ad9361*.h
%{_libdir}/libad9361.so
%{_libdir}/pkgconfig/libad9361.pc

%files devel-doc
%{_docdir}/%{name}/html

%changelog
* Wed May 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Sat Jul 15 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to release 0.3
  * build,.travis.yml: drop xcode 8 build by @commodo in #41
  * CI/travis/after_deploy: trigger gr-iio build when done by @commodo in #42
  * Fix rate checks by @tfcollins in #43
  * build,centos,bionic: add ssh-dss algo to EXTRA_SSH env-var by @commodo in #45
  * .travis.yml: force xenial for docker builds by @commodo in #46
  * build,.travis.yml: update the build configuration by @commodo in #49
  * ci,os-x: reduce build times by not upgrading by @commodo in #50
  * ci,build: various updates by @commodo in #54
  * ci,travis: add CentOS 8 & Ubuntu 20.04 builds by @commodo in #59
  * Update HW test to use environmental variables by @tfcollins in #58
  * ci,azure-pipelines: add initial yaml file by @commodo in #61
  * ci,azure-pipelines: use matrix strategy, and user artifacts from libiio's pipeline by @commodo in #62
  * cmake: change build define LIBIIO_EXPORTS to LIBAD9361_EXPORTS by @adisuciu in #64
  * Minor fix to for loop for testing rates by @SrikanthPagadarai in #63
  * Fix Centos builds which have bad version of cmake by @tfcollins in #69
  * cmake: add "uninstall" target by @willcode in #68
  * Add python bindings by @tfcollins in #70
  * Make library check for python optional by @tfcollins in #71
  * Fix flags for FMComms5 python tests by @tfcollins in #74
  * CI: update azure-pipelines.yml file by @ccraluca in #77
  * CI: remove libiio scripts dependencies and update CI folder by @ccraluca in #79
  * CI:change os versions to match os version used on libiio by @ccraluca in #80
  * Staging/fix arm builds by @ccraluca in #81
  * Add readme for python bindings by @tfcollins in #83
  * CI: add python deployment by @ccraluca in #84
  * CI:update ci by @ccraluca in #85
  * CI update: remove builds with deprecated OS version by @ccraluca in #86
  * Minor fixes before release by @tfcollins in #88
  * Doc updates by @tfcollins in #90
  * CI:add tags on CI triggers by @ccraluca in #92
  * CI: fix fetch error by @ccraluca in #93
* Thu Dec 24 2020 Martin Hauke <mardnh@gmx.de>
- Use github source URL
- Update patch libad9361-iio-lib-dir.patch to also fix the
  pkgconfig file
- Run spec-cleaner
- Package license file
* Sat Dec 22 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to release 0.1
* Tue Dec  5 2017 wk@ire.pw.edu.pl
- git 20171204
* Tue Aug 22 2017 wk@ire.pw.edu.pl
- initial build
- git 20170207
